@@ -5,7 +5,7 @@ import os
 import logging
 
 
-log = logging.getLogger(__name__)
+_moduleLogger = logging.getLogger(__name__)
 
 
 class Audiobook(object):
@@ -23,11 +23,16 @@ class Audiobook(object):
         elif is_single_chapter(path):
             self._scan_chapter(path)
         else:
-            log.info("Audiobook not found in path: " + path)
+            _moduleLogger.info("Audiobook not found in path: " + path)
             raise IOError("Audiobook directory not found")
 
         if len(self._chapterPaths) <= self.current_chapter:
-            raise Exception("Unknown chapter set")
+			_moduleLogger.warning(
+				"Audiobook chapter out of range (%s/%s)" % (
+					self.current_chapter, len(self._chapterPaths)
+				)
+			)
+			self.current_chapter = 0
 
     @property
     def chapters(self):
