@@ -359,7 +359,7 @@ class Gui(object):
             else:
                 orientation = gtk.ORIENTATION_HORIZONTAL
             self.set_orientation(orientation)
-        if self.__settingsManager.get_audiobook_path != self.controller.get_books_path():
+        if self.__settingsManager.get_audiobook_path() != self.controller.get_books_path():
             self.controller.load_books_path(self.__settingsManager.get_audiobook_path())
 
         return True
@@ -534,7 +534,7 @@ class Gui(object):
         _moduleLogger.debug("new books")
         del self._bookSelection[:]
         self._bookSelection.extend(books)
-        if len(books) == 0:
+        if len(books) == 0 and self.controller is not None:
             hildonize.show_information_banner(self.win, "No audiobooks found. \nPlease place your audiobooks in the directory %s" % self.controller.get_books_path())
 
     def set_book(self, bookPath, cover):
@@ -557,7 +557,7 @@ class Gui(object):
         '''
         self.auto_chapter_selected = True
         if hildonize.IS_FREMANTLE_SUPPORTED:
-            self.chapter_button.set_text("Chapter", chapterIndex)
+            self.chapter_button.set_text("Chapter", str(chapterIndex))
         else:
             self._chapterMenuItem.get_child().set_text("Chapter: %s" % (chapterIndex, ))
 
