@@ -9,7 +9,7 @@ import Audiobook
 import FileStorage
 
 
-log = logging.getLogger(__name__)
+_moduleLogger = logging.getLogger(__name__)
 
 
 class Player(object):
@@ -32,6 +32,10 @@ class Player(object):
         return self._bookDir
 
     def load_books_path(self, booksPath):
+        if self.audiobook is not None:
+            position = self.player.elapsed()
+            self.storage.set_time(self.audiobook.current_chapter, position)
+
         self._bookDir = booksPath
 
         self._bookPaths = dict(
@@ -45,14 +49,14 @@ class Player(object):
 
         lastBookName = self.storage.get_selected()
         if lastBookName is not None:
-            log.info("continuing book: %s" % lastBookName)
+            _moduleLogger.info("continuing book: %s" % lastBookName)
             try:
                 bookPath = self._bookPaths[lastBookName]
                 self.set_book(bookPath)
             except KeyError:
-                log.info("Audiobook was not found")
+                _moduleLogger.info("Audiobook was not found")
             except IOError:
-                log.info("Audiobook could not be loaded")
+                _moduleLogger.info("Audiobook could not be loaded")
 
     @staticmethod
     def __format_name(path):
@@ -86,7 +90,7 @@ class Player(object):
         self.set_chapter(chapter_title, True)
 
     def set_chapter(self, chapter, continuing = False):
-        log.info("set chapter:" + chapter + " : Continuing: " + str(continuing))
+        _moduleLogger.info("set chapter:" + chapter + " : Continuing: " + str(continuing))
         self.audiobook.set_chapter(chapter)
         self.player.set_file(self.audiobook.get_current_chapter())
         if not continuing:
@@ -96,7 +100,7 @@ class Player(object):
             self.ui.set_chapter(self.audiobook.current_chapter)
 
     def previous_chapter(self, *args):
-        log.info("Going back a chapter")
+        _moduleLogger.info("Going back a chapter")
         self.player.stop()
         next_file = self.audiobook.get_previous_chapter()
         if next_file is not False:
@@ -106,7 +110,7 @@ class Player(object):
             self.storage.set_time(0, 0)
 
     def next_chapter(self, *args):
-        log.info("Advancing a chapter")
+        _moduleLogger.info("Advancing a chapter")
         self.player.stop()
         next_file = self.audiobook.get_next_chapter()
         if next_file is not False:
@@ -130,7 +134,6 @@ class Player(object):
         position = self.player.elapsed()
         self.player.stop()
 
-        #print "stopped at ", position
         if self.audiobook is not None:
             self.storage.set_time(self.audiobook.current_chapter, position)
 
